from __future__ import print_function
import ctypes, sys


def is_admin():
    try:
        return ctypes.windll.shell32.IsUserAnAdmin()
    except:
        return False

def need_admin(filename):
    def func_de(func):
        if is_admin():
            def func_wrap(*args, **kwargs):
                func(*args,**kwargs);
            return func_wrap;
        else:
            ctypes.windll.shell32.ShellExecuteW(None, "runas", sys.executable, filename, None, 1);
    return func_de;









    


import requests
import wmi;
class GETEWays:
    BASE_URL = "";
    net_label = "";
    NIC  = None;
    def __init__(self,baseurl,net_label):
        self.BASE_URL = baseurl;
        self.net_label = net_label;
    """
    获取网关
    """
    def get_net(self):
        url = f"{self.BASE_URL}/api/net"
        headers = {
        'User-Agent': 'apifox/1.0.0 (https://www.apifox.cn)'
        }
        net_json = requests.request("GET", url, headers=headers, timeout=10).json();
        return net_json;

    """
    获取固定网关
    """
    def get_fixed(self):
        url = f"{self.BASE_URL}/api/fixedip/geteway"
        headers = {
        'User-Agent': 'apifox/1.0.0 (https://www.apifox.cn)'
        }
        fixed_net_json = requests.request("GET", url, headers=headers, timeout=10).json();
        return fixed_net_json;
    """
    设置网关
    """
    def set_geteway(self,_status='enableDHCP'):
        if self.NIC is None:
            wlan_int_id = None
            #设定对哪个可用网络设备进行设置，确保这个设备可用而不是被禁用。
            # net_label = u'本地连接'
            for nic in wmi.WMI().Win32_NetworkAdapter():
                if nic.NetConnectionID == self.net_label:
                    wlan_int_id = nic.Index
                    break
            if wlan_int_id != None:
                for nic in wmi.WMI().Win32_NetworkAdapterConfiguration(IPEnabled=1):
                    if nic.Index == wlan_int_id:
                        if type(_status) == dict:
                            NIC = nic;
                            nic.SetGateways(DefaultIPGateway=[_status['gateway']])
                        elif 'enableDHCP' == _status:
                            nic.EnableDHCP()
            else:
                print('error,id is empty!')
        else:
           self.NIC.SetGateways(DefaultIPGateway=[_status['gateway']])

    """
    重启网关
    """
    def reset_geteway(self,current_getaway):
        url = f"http://{current_getaway}/goform/goform_set_cmd_process"
        #   url2 = "http://192.168.0.1/goform/goform_set_cmd_process"
        headers = {
            "Accept": "application/json, text/javascript, */*; q=0.01",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Connection": "keep-alive",
            "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
            "Host": current_getaway,
            "Origin": f"http://{current_getaway}",
            "Referer": f"http://{current_getaway}/index.html",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.131 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest"
        }

        data2 = {
            "isTest": "false",
            "goformId": "LOGIN",
            "password": "YWRtaW4="
        }
        requests.post(url=url, data=data2, headers=headers,timeout=5)
        data = {
                "isTest": "false",
                "goformId": "REBOOT_DEVICE"
        }
        requests.post(url=url, data=data, headers=headers,timeout=5)







import logging
from cmq.account import Account
from cmq.queue import Message

class TxYunMessageUtils:
    def __init__(self,secretId,secretKey) -> None:
        self.secretId = secretId;
        self.secretKey = secretKey
        self.my_account = Account("https://cmq-queue-gz.api.qcloud.com",
                            secretId, secretKey, debug=True)

    def getQueue(self,queue_name):
        self.my_account.set_log_level(logging.DEBUG)
        my_queue = self.my_account.get_queue(queue_name)
        return my_queue

    def send_message(self,queue_name,messagebody):
        self.my_account.set_log_level(logging.DEBUG)
        msg_body = messagebody
        msg = Message(msg_body)
        my_queue = self.my_account.get_queue(queue_name)
        my_queue.send_message(msg)


from apscheduler.schedulers.blocking import BlockingScheduler
# 输出时间


class ThSchedulers:
    jobs = [];

    def add_jobs(self,**kwargs):
        def inner_function(func):
                self.jobs.append((func,kwargs));
        return inner_function;

    def __init__(self) -> None:
        self.scheduler = BlockingScheduler()

        
    def start(self):
        for item in self.jobs:
            self.scheduler.add_job(item[0], 'cron', **item[1]);
        self.scheduler.start()




from th_spider_core.geteway import GETEWays;
class GetewayTransation():
    getewayIns:GETEWays
    current_getway:str
    fiexd_geteway:str

    def __init__(self,baseurl,net_label) -> None:
        self.getewayIns = GETEWays(baseurl=baseurl,net_label=net_label)
        geteway = self.getewayIns.get_net();
        fixed_geteway = self.getewayIns.get_fixed();
        self.current_getway = geteway["geteway"];
        self.getewayIns.set_geteway({"gateway":self.current_getway});
        self.fiexd_geteway  = fixed_geteway["geteway"];


    def transation(self,func):
        def wrap_func(*args, **kwargs):
            flag = func(*args,**kwargs);
            if flag == False or flag is None:
                self.getewayIns.reset_geteway(self.current_getway)
                geteway = self.getewayIns.get_net();
                self.current_getway = geteway["geteway"];
                self.getewayIns.set_geteway({"gateway":self.current_getway});
            return flag;
        return wrap_func;



    def fixed_net_do(self,func):
        def wrap_func(*args, **kwargs):
            self.getewayIns.set_geteway({"gateway":self.fiexd_geteway});
            data = func(*args,**kwargs);
            self.getewayIns.set_geteway({"gateway":self.current_getway});
            return data;
        return wrap_func;


from th_txmessage.utils.tx_ms_utils import TxYunMessageUtils
import traceback
import json


class TxyunMessage:
    message_deal_process = {}
    
    def message_deal(self, messageType):
        def wrap(func):
            self.message_deal_process[messageType] = func
            return func
        return wrap

    def __init__(self, qname, secretId, secretKey) -> None:
        self.qname = qname
        self.secretId = secretId
        self.secretKey = secretKey
        txyunUtils = TxYunMessageUtils(self.secretId, self.secretKey)
        self.txyunUtils = txyunUtils;

    def listent(self):
        while True:
            try:
                myQueue = self.txyunUtils.getQueue(self.qname)
                recv_msg = myQueue.receive_message(30)
            except Exception as e:
                pass
            else:
                try:
                    messageBody = json.loads(recv_msg.msgBody)
                    if "lx" not in messageBody.keys() or "data" not in messageBody.keys():
                        myQueue.delete_message(recv_msg.receiptHandle)
                    else:
                        flag = self.run(
                            message_type=messageBody["lx"], message_body=messageBody["data"])
                        if flag == True:
                            myQueue.delete_message(recv_msg.receiptHandle)
                except Exception as e:
                    traceback.print_exc()
                    print("消息删除失败")

    def run(self, message_type, message_body):
        if message_type in self.message_deal_process.keys():
            return self.message_deal_process[message_type](message_body)



from setuptools import setup,find_packages

setup(name='th_txmessage',  # 打包后的包文件名
    version='2.1',    #版本号
    description='听海内部爬虫核心类库',  # 说明
    long_description="听海爬虫组一些核心代码集合",  #详细说明
    license="MIT Licence",  # 许可
    url='',
    author='wzr',
    author_email='510540795@qq.com',
    packages=find_packages(),     #这个参数是导入目录下的所有__init__.py包
    include_package_data=True,
    platforms="any",
    py_modules=["th_txmessage"],
    install_requires=["qcloud-cmq-sdk-py3","requests"],    # 引用到的第三方库
    # py_modules=['pip-test.DoRequest', 'pip-test.GetParams', 'pip-test.ServiceRequest',
    #             'pip-test.ts.constants', 'pip-test.ac.Agent2C',
    #             'pip-test.ts.ttypes', 'pip-test.ac.constants',
    #             'pip-test.__init__'],  # 你要打包的文件，这里用下面这个参数代替
    # packages=[''] # 这个参数是导入目录下的所有__init__.py包
)